<?php
$errors = [];

// Check if the form was submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {

    // Collect form data and validate required fields
    $first_name = $_POST['first_name'] ?? '';
    $last_name = $_POST['last_name'] ?? '';
    $email = $_POST['email'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $month = $_POST['month'] ?? '';
    $day = $_POST['day'] ?? '';
    $year = $_POST['year'] ?? '';
    $uwm_student = $_POST['uwm_student'] ?? '';
    $areas_of_interest = $_POST['interests'] ?? [];
    $comments = $_POST['comments'] ?? '';

    // Validate form fields and add errors for missing fields
    if (empty($last_name)) {
        $errors[] = 'Please go back and enter your last name.';
    }
    if (empty($email)) {
        $errors[] = 'Please go back and enter your email.';
    }
    if (empty($phone)) {
        $errors[] = 'Please go back and enter your phone number.';
    }
    if (empty($day)) {
        $errors[] = 'Please go back and enter a day.';
    }
    if (empty($year)) {
        $errors[] = 'Please go back and enter a year.';
    }
    if (empty($uwm_student)) {
        $errors[] = 'Please go back and check if you are a UWM student.';
    }
    if (empty($areas_of_interest)) {
        $errors[] = 'Please go back and check which area(s) you are interested in.';
    }
    if (empty($comments)) {
        $errors[] = 'Please go back and enter your comments.';
    }

    // Start HTML output
    echo "
    <html>
    <head>
        <title>Form Submission</title>
        <style>
            body {
                background-color: #c0d6e4;
                font-family: Arial, sans-serif;
                text-align: center;
                padding-top: 50px;
            }
            .result-container {
                background-color: white;
                padding: 20px;
                margin: 0 auto;
                width: 600px;
                border: 1px solid #ccc;
                box-shadow: 2px 2px 10px rgba(0, 0, 0, 0.1);
            }

            .logo {
                display: block;
                margin: 0 auto 20px;
                width: 150px;
                height: auto;
            }
            h1, h2 {
                margin-bottom: 20px;
            }
            p {
                text-align: left;
                margin-bottom: 10px;
            }
            .go-back-btn {
                margin-top: 20px;
                padding: 10px 20px;
                background-color: #0073e6;
                color: white;
                border: none;
                cursor: pointer;
                border-radius: 4px;
            }
        </style>
    </head>
    <body>
        <div class='result-container'>
            <img src='download.png' alt='UWM Logo' class='logo'>
            
            <h1>UWM Information Request Form</h1>
            <h2>Hugues Bolembe | Assignment 4-5</h2>
    ";

    // Check if there are any missing fields
    if (!empty($errors)) {
        echo "<h3>Missing Information:</h3>";
        foreach ($errors as $error) {
            echo "<p>$error</p>";
        }
        echo "<p>Please go back and fill out the form again.</p>";
    } else {
        // If no errors, display the submitted information
        echo "<p><strong>First Name:</strong> " . htmlspecialchars($first_name) . "</p>";
        echo "<p><strong>Last Name:</strong> " . htmlspecialchars($last_name) . "</p>";
        echo "<p><strong>Email:</strong> " . htmlspecialchars($email) . "</p>";
        echo "<p><strong>Phone:</strong> " . htmlspecialchars($phone) . "</p>";
        echo "<p><strong>Birthday:</strong> " . htmlspecialchars($month) . "/" . htmlspecialchars($day) . "/" . htmlspecialchars($year) . "</p>";
        echo "<p><strong>Are you a UWM student?:</strong> " . htmlspecialchars($uwm_student) . "</p>";
        echo "<p><strong>Areas of Interest:</strong> " . implode(", ", $areas_of_interest) . "</p>";
        echo "<p><strong>Comments:</strong> " . htmlspecialchars($comments) . "</p>";
        echo "<p>Thank you for submitting the form.</p>";
    }

    // Go back button
    echo "
            <button class='go-back-btn' onclick='history.back()'>Go back</button>
        </div>
    </body>
    </html>
    ";
}
?>
